@@ -46,7 +46,7 @@ class GLib::Instantiatable
       unless called
         called = true
         signal_handler_disconnect(sid)
-        proc.call(args) end }
+        proc.call(*args) end }
     sid end
   alias ssc_atonce safety_signal_connect_atonce
 
@@ -314,7 +314,6 @@ module Gtk
             command = o
             throw :urlopen end } end
       command end
-    memoize :url_open_command
   end
 end
 
